@@ -2,21 +2,21 @@ require(xgboost)
 require(Matrix)
 require(data.table)
 if (!require(vcd)) {
-  install.packages('vcd') #Available in Cran. Used for its dataset with categorical values.
+  install.packages('vcd') #Available in CRAN. Used for its dataset with categorical values.
   require(vcd)
 }
-# According to its documentation, Xgboost works only on numbers.
+# According to its documentation, XGBoost works only on numbers.
 # Sometimes the dataset we have to work on have categorical data.
 # A categorical variable is one which have a fixed number of values. By example, if for each observation a variable called "Colour" can have only "red", "blue" or "green" as value, it is a categorical variable.
 #
 # In R, categorical variable is called Factor.
 # Type ?factor in console for more information.
 #
-# In this demo we will see how to transform a dense dataframe with categorical variables to a sparse matrix before analyzing it in Xgboost.
+# In this demo we will see how to transform a dense dataframe with categorical variables to a sparse matrix before analyzing it in XGBoost.
 # The method we are going to see is usually called "one hot encoding".
 
 #load Arthritis dataset in memory.
-data(Arthritis)
+data(Arthritis, package = "vcd")
 
 # create a copy of the dataset with data.table package (data.table is 100% compliant with R dataframe but its syntax is a lot more consistent and its performance are really good).
 df <- data.table(Arthritis, keep.rownames = FALSE)
@@ -25,13 +25,13 @@ df <- data.table(Arthritis, keep.rownames = FALSE)
 cat("Print the dataset\n")
 print(df)
 
-# 2 columns have factor type, one has ordinal type (ordinal variable is a categorical variable with values wich can be ordered, here: None > Some > Marked).
+# 2 columns have factor type, one has ordinal type (ordinal variable is a categorical variable with values which can be ordered, here: None > Some > Marked).
 cat("Structure of the dataset\n")
 str(df)
 
 # Let's add some new categorical features to see if it helps. Of course these feature are highly correlated to the Age feature. Usually it's not a good thing in ML, but Tree algorithms (including boosted trees) are able to select the best features, even in case of highly correlated features.
 
-# For the first feature we create groups of age by rounding the real age. Note that we transform it to factor (categorical data) so the algorithm treat them as independant values.
+# For the first feature we create groups of age by rounding the real age. Note that we transform it to factor (categorical data) so the algorithm treat them as independent values.
 df[, AgeDiscret := as.factor(round(Age / 10, 0))]
 
 # Here is an even stronger simplification of the real age with an arbitrary split at 30 years old. I choose this value based on nothing. We will see later if simplifying the information based on arbitrary values is a good strategy (I am sure you already have an idea of how well it will work!).
